@@ -16,20 +16,22 @@ function(
     }
     file.a<-tempfile(pattern="ascores",tmpdir=tempdir())
     file.b<-tempfile(pattern="bscores",tmpdir=tempdir())
-    repeat{
-      index<-sample(data[,1],replace=FALSE)
+    
+    for(it in 1:number)
+    {
+      index<-if(it==1) data[,1] else sample(data[,1],replace=FALSE)
       scores.a<-data[,2][index=="A"]
       scores.a<-as.matrix(scores.a)
       scores.a<-t(scores.a)
       write.table(scores.a,file=file.a,append=TRUE,col.names=FALSE,row.names=FALSE)
-      ascores<-read.table(file.a)
       scores.b<-data[,2][index=="B"]
       scores.b<-as.matrix(scores.b)
       scores.b<-t(scores.b)
       write.table(scores.b,file=file.b,append=TRUE,col.names=FALSE,row.names=FALSE)
-      bscores<-read.table(file.b)
-      if(nrow(bscores)==number)break
     }
+    ascores<-read.table(file.a)
+    bscores<-read.table(file.b)
+    
     ascores<-as.matrix(ascores)
     mean.a<-numeric(number)
     for(it in 1:number){
@@ -82,24 +84,30 @@ function(
     file.b<-tempfile(pattern="bscores",tmpdir=tempdir())
     MT<-nrow(data)
     ab<-c("A","B")
-    repeat{
-      index<-numeric()
-      repeat{
-        index<-c(index,sample(ab,2,replace=FALSE))
-        if(length(index)==MT)break
+    
+    for(it in 1:number)
+    {
+      if(it==1) 
+        index<-data[,1] 
+      else{
+        index<-numeric()
+        repeat{
+          index<-c(index,sample(ab,2,replace=FALSE))
+          if(length(index)==MT)break
+        }
       }
       scores.a<-data[,2][index=="A"]
       scores.a<-as.matrix(scores.a)
       scores.a<-t(scores.a)
       write.table(scores.a,file=file.a,append=TRUE,col.names=FALSE,row.names=FALSE)
-      ascores<-read.table(file.a)
       scores.b<-data[,2][index=="B"]
       scores.b<-as.matrix(scores.b)
       scores.b<-t(scores.b)
       write.table(scores.b,file=file.b,append=TRUE,col.names=FALSE,row.names=FALSE)
-      bscores<-read.table(file.b)
-      if(nrow(bscores)==number)break
     }
+    ascores<-read.table(file.a)
+    bscores<-read.table(file.b)
+    
     ascores<-as.matrix(ascores)
     mean.a<-numeric(number)
     for(it in 1:number){
@@ -152,39 +160,49 @@ function(
     file.b<-tempfile(pattern="bscores",tmpdir=tempdir())
     MT<-nrow(data)
     N<-c(rep(0,MT/2),rep(1,MT/2))
-    repeat{
-      index<-matrix(0,ncol=MT)
-      index<-rbind(sample(N,MT,replace=FALSE))
-      check<-numeric()
-      for(itr in 1:(MT-limit)){
-        check2<-0
-        for(it in itr:(itr+limit)){
-          check2<-check2+index[,it]
-        }
-        check<-cbind(check,check2)
-      }
-      if(sum(check==(limit+1)|check==0)==0){
-        for(it in 1:(length(index))){
-          if(index[,it]==0){
-            index[,it]<-"A"
+    
+    for(i in 1:number)
+    {
+      if(i==1)
+        index<-data[,1] 
+      else{
+        repeat{
+          index<-rbind(sample(N,MT,replace=FALSE))
+          check<-numeric()
+          for(itr in 1:(MT-limit)){
+            check2<-0
+            for(it in itr:(itr+limit)){
+              check2<-check2+index[,it]
+            }
+            check<-cbind(check,check2)
           }
-          else{
-            index[,it]<-"B"
+          
+          if(sum(check==(limit+1)|check==0)==0){
+            for(it in 1:(length(index))){
+              if(index[,it]==0){
+                index[,it]<-"A"
+              }
+              else{
+                index[,it]<-"B"
+              }
+            }
+            break
           }
         }
-        scores.a<-data[,2][index=="A"]
-        scores.b<-data[,2][index=="B"]
-        scores.a<-as.matrix(scores.a)
-        scores.a<-t(scores.a)
-        write.table(scores.a,file=file.a,append=TRUE,col.names=FALSE,row.names=FALSE)
-        ascores<-read.table(file.a)
-        scores.b<-as.matrix(scores.b)
-        scores.b<-t(scores.b)
-        write.table(scores.b,file=file.b,append=TRUE,col.names=FALSE,row.names=FALSE)
-        bscores<-read.table(file.b)
-        if(nrow(bscores)==number)break
       }
+      
+      scores.a<-data[,2][index=="A"]
+      scores.a<-as.matrix(scores.a)
+      scores.a<-t(scores.a)
+      write.table(scores.a,file=file.a,append=TRUE,col.names=FALSE,row.names=FALSE)
+      scores.b<-data[,2][index=="B"]
+      scores.b<-as.matrix(scores.b)
+      scores.b<-t(scores.b)
+      write.table(scores.b,file=file.b,append=TRUE,col.names=FALSE,row.names=FALSE)
     }
+    ascores<-read.table(file.a)
+    bscores<-read.table(file.b)
+    
     ascores<-as.matrix(ascores)
     mean.a<-numeric(number)
     for(it in 1:number){
@@ -233,18 +251,20 @@ function(
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
+    
     observed<-data[,2]
     MT<-nrow(data)
     quantity<-choose(MT-2*limit+1,1)
-    selection<-sample(1:quantity,number,replace=TRUE)
+    selection<-sample(1:quantity,number-1,replace=TRUE)
     index.a<-limit:(MT-limit)
-    scores.a<-list()
-    for(it in 1:number){
-      scores.a[[it]]<-c(observed[1:index.a[selection[it]]])
+    
+    scores.a<-list(data[,2][data[,1]=="A"])
+    for(it in 1:(number-1)){
+      scores.a[[it+1]]<-c(observed[1:index.a[selection[it]]])
     }
-    scores.b<-list()
-    for(it in 1:number){
-      scores.b[[it]]<-c(observed[(1+index.a[selection[it]]):length(observed)])
+    scores.b<-list(data[,2][data[,1]=="B"])
+    for(it in 1:(number-1)){
+      scores.b[[it+1]]<-c(observed[(1+index.a[selection[it]]):length(observed)])
     }
     distribution<-numeric(number)
     
@@ -282,10 +302,11 @@ function(
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
+    
     observed<-data[,2]
     MT<-nrow(data)
     quantity<-choose(MT-3*limit+2,2)
-    selection<-sample(1:quantity,number,replace=TRUE)
+    selection<-sample(1:quantity,number-1,replace=TRUE)
     index1<-1:(MT-3*limit+1)
     index2<-rev(index1)
     index.a<-numeric()
@@ -298,17 +319,18 @@ function(
         index.b<-c(index.b,2*limit-1+it)
       }
     }
-    scores.a1<-list()
-    for(it in 1:number){
-      scores.a1[[it]]<-c(observed[1:(index.a[selection[it]])])
+    
+    scores.a1<-list(data[,2][data[,1]=="A1"])
+    for(it in 1:(number-1)){
+      scores.a1[[it+1]]<-c(observed[1:(index.a[selection[it]])])
     }
-    scores.b1<-list()
-    for(it in 1:number){
-      scores.b1[[it]]<-c(observed[(1+index.a[selection[it]]):(index.b[selection[it]])])
+    scores.b1<-list(data[,2][data[,1]=="B1"])
+    for(it in 1:(number-1)){
+      scores.b1[[it+1]]<-c(observed[(1+index.a[selection[it]]):(index.b[selection[it]])])
     }
-    scores.a2<-list()
-    for(it in 1:number){
-      scores.a2[[it]]<-c(observed[(1+index.b[selection[it]]):(MT)])
+    scores.a2<-list(data[,2][data[,1]=="A2"])
+    for(it in 1:(number-1)){
+      scores.a2[[it+1]]<-c(observed[(1+index.b[selection[it]]):(MT)])
     }
     scores.a<-list()
     for(it in 1:number){
@@ -403,19 +425,21 @@ function(
     if(save=="yes"){
       file<-file.choose(new=FALSE)
     }
+    
     observed<-data[,2]
     MT<-nrow(data)
     quantity<-choose(MT-4*limit+3,3)
-    selection<-sample(1:quantity,number,replace=TRUE)
+    selection<-sample(1:quantity,number-1,replace=TRUE)
     index1<-1:(MT-4*limit+1)
     index2<-rev(cumsum(index1))
+    
     index.a1<-numeric()
     for(it in 1:length(index1)){
       index.a1<-c(index.a1,(rep((limit+index1[it]-1),index2[it])))
     }
-    scores.a1<-list()
-    for(it in 1:number){
-      scores.a1[[it]]<-c(observed[1:(index.a1[selection[it]])])
+    scores.a1<-list(data[,2][data[,1]=="A1"])
+    for(it in 1:(number-1)){
+      scores.a1[[it+1]]<-c(observed[1:(index.a1[selection[it]])])
     }
     index.b1<-numeric()
     for(itr in index1){
@@ -423,9 +447,9 @@ function(
         index.b1<-c(index.b1,rep((2*limit+it),(MT-4*limit+1-it)))
       }
     }
-    scores.b1<-list()
-    for(it in 1:number){
-      scores.b1[[it]]<-c(observed[(1+index.a1[selection[it]]):index.b1[selection[it]]])
+    scores.b1<-list(data[,2][data[,1]=="B1"])
+    for(it in 1:(number-1)){
+      scores.b1[[it+1]]<-c(observed[(1+index.a1[selection[it]]):index.b1[selection[it]]])
     }
     indexa2<-numeric()
     for(it in 1:length(index1)){
@@ -435,13 +459,13 @@ function(
     for(it in 1:length(indexa2)){
       index.a2<-c(index.a2,(4*limit-limit-1+(indexa2[it]:length(index1))))
     }
-    scores.a2<-list()
-    for(it in 1:number){
-      scores.a2[[it]]<-c(observed[(1+index.b1[selection[it]]):index.a2[selection[it]]])
+    scores.a2<-list(data[,2][data[,1]=="A2"])
+    for(it in 1:(number-1)){
+      scores.a2[[it+1]]<-c(observed[(1+index.b1[selection[it]]):index.a2[selection[it]]])
     }
-    scores.b2<-list()
-    for(it in 1:number){
-      scores.b2[[it]]<-c(observed[(1+index.a2[selection[it]]):MT])
+    scores.b2<-list(data[,2][data[,1]=="B2"])
+    for(it in 1:(number-1)){
+      scores.b2[[it+1]]<-c(observed[(1+index.a2[selection[it]]):MT])
     }
     scores.a<-list()
     for(it in 1:number){
@@ -553,49 +577,54 @@ function(
     N<-ncol(data)/2
     MT<-nrow(data)
     readLines(con=starts,n=N)->startpoints
-    limits<-list()
-    for(it in 1:N){
-      limits[[it]]<-startpoints[it]
-    }
-    for(it in 1:N){
-      limits[[it]]<-strsplit(limits[[it]],"\t")
-    }
+    limits<-strsplit(startpoints,"\\s")
+    limits<-lapply(limits,function(x){x[x!=""]})
+    
     numbers<-numeric(N)
     for(it in 1:N){
-      numbers[it]<-length(limits[[it]][[1]])
+      numbers[it]<-length(limits[[it]])
     }
     fileCOMBSTARTPTS<-tempfile(pattern="startpoints",tmpdir=tempdir())
     repeat{
       startpt<-numeric(N)
       for(it in 1:N){
         if(numbers[it]!=1){
-          startpt[it]<-sample(limits[[it]][[1]],1)
+          startpt[it]<-sample(limits[[it]],1)
         }
         else{
-          startpt[it]<-limits[[it]][[1]]
+          startpt[it]<-limits[[it]]
         }
       }
       selectdesign<-sample(startpt,replace=FALSE)
       selectdesign1<-rbind(selectdesign)
       write.table(selectdesign1,file=fileCOMBSTARTPTS,append=TRUE,col.names=FALSE,row.names=FALSE)
       combstartpts<-read.table(fileCOMBSTARTPTS)
-      if(nrow(combstartpts)==number)break
+      if(nrow(combstartpts)==(number-1))break
     }
-    scores.a<-list()
-    for(iter in 1:number){
+    
+    ascores<-list()
+    for(it in 1:N){
+      ascores[[it]]<-data[,it*2][data[,it*2-1]=="A"]
+    }
+    scores.a<-list(ascores)
+    for(iter in 1:(number-1)){
       ascores<-list()
       for(it in 1:N){
         ascores[[it]]<-data[1:(combstartpts[iter,it]-1),it*2]
       }
-      scores.a[[iter]]<-ascores
+      scores.a[[iter+1]]<-ascores
     }
-    scores.b<-list()
-    for(iter in 1:number){
+    bscores<-list()
+    for(it in 1:N){
+      bscores[[it]]<-data[,it*2][data[,it*2-1]=="B"]
+    }
+    scores.b<-list(bscores)
+    for(iter in 1:(number-1)){
       bscores<-list()
       for(it in 1:N){
         bscores[[it]]<-data[combstartpts[iter,it]:MT,it*2]
       }
-      scores.b[[iter]]<-bscores
+      scores.b[[iter+1]]<-bscores
     }
     differs<-list()
     
@@ -660,15 +689,15 @@ function(
     
     observed<-data[,2]
     assignments<-read.table(assignments)
-    selection<-sample.int(nrow(assignments),number,replace=TRUE)
+    selection<-sample.int(nrow(assignments),number-1,replace=TRUE)
     
-    scores.a<-list()
-    for(it in 1:number)
-      scores.a[[it]]<-c(observed[assignments[selection[it],]=="A"])
+    scores.a<-list(data[,2][data[,1]=="A"])
+    for(it in 1:(number-1))
+      scores.a[[it+1]]<-c(observed[assignments[selection[it],]=="A"])
     
-    scores.b<-list()
-    for(it in 1:number)
-      scores.b[[it]]<-c(observed[assignments[selection[it],]=="B"])
+    scores.b<-list(data[,2][data[,1]=="B"])
+    for(it in 1:(number-1))
+      scores.b[[it+1]]<-c(observed[assignments[selection[it],]=="B"])
     
     distribution<-numeric(number)
     if(statistic=="A-B"){
