@@ -7,12 +7,17 @@ function(design,statistic,data=read.table(file.choose(new=FALSE))){
     if(statistic=="A-B"){
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
+    else if(statistic=="B-A"){
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
+    else if(statistic=="|A-B|"){
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
+    else{
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
   }
   
   if(design=="ABA"){
@@ -23,30 +28,38 @@ function(design,statistic,data=read.table(file.choose(new=FALSE))){
     if(statistic=="A-B"){
       observed.statistic<-mean(observed.a)-mean(observed.b1)
     }
-    if(statistic=="B-A"){
+    else if(statistic=="B-A"){
       observed.statistic<-mean(observed.b1)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
+    else if(statistic=="|A-B|"){
       observed.statistic<-abs(mean(observed.a)-mean(observed.b1))
     }
-    if(statistic=="PA-PB"){
+    else if(statistic=="PA-PB"){
       observed.statistic<-((mean(observed.a1)+mean(observed.a2))/2)-(mean(observed.b1))
     }
-    if(statistic=="PB-PA"){
+    else if(statistic=="PB-PA"){
       observed.statistic<-mean(observed.b1)-((mean(observed.a1)+mean(observed.a2))/2)
     }
-    if(statistic=="|PA-PB|"){
+    else if(statistic=="|PA-PB|"){
       observed.statistic<-abs(((mean(observed.a1)+mean(observed.a2))/2)-mean(observed.b1))
     }
-    if(statistic=="AA-BB"){
+    else if(statistic=="AA-BB"){
       observed.statistic<-(mean(observed.a1)+mean(observed.a2))-(mean(observed.b1))
     }
-    if(statistic=="BB-AA"){
+    else if(statistic=="BB-AA"){
       observed.statistic<-(mean(observed.b1))-(mean(observed.a1)+mean(observed.a2))
     }
-    if(statistic=="|AA-BB|"){
+    else if(statistic=="|AA-BB|"){
       observed.statistic<-abs((mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)))
     }
+    else{
+      A1<-observed.a1
+      B1<-observed.b1	
+      A2<-observed.a2
+      A<-observed.a
+      B<-observed.b1
+      observed.statistic<-eval(parse(text=statistic))
+    }
   }
   
   if(design=="ABAB"){
@@ -59,30 +72,39 @@ function(design,statistic,data=read.table(file.choose(new=FALSE))){
     if(statistic=="A-B"){
       observed.statistic<-mean(observed.a)-mean(observed.b)
     }
-    if(statistic=="B-A"){
+    else if(statistic=="B-A"){
       observed.statistic<-mean(observed.b)-mean(observed.a)
     }
-    if(statistic=="|A-B|"){
+    else if(statistic=="|A-B|"){
       observed.statistic<-abs(mean(observed.a)-mean(observed.b))
     }
-    if(statistic=="PA-PB"){
+    else if(statistic=="PA-PB"){
       observed.statistic<-((mean(observed.a1)+mean(observed.a2))/2)-((mean(observed.b1)+mean(observed.b2))/2)	
     }
-    if(statistic=="PB-PA"){
+    else if(statistic=="PB-PA"){
       observed.statistic<-((mean(observed.b1)+mean(observed.b2))/2)-((mean(observed.a1)+mean(observed.a2))/2)
     }
-    if(statistic=="|PA-PB|"){
+    else if(statistic=="|PA-PB|"){
       observed.statistic<-abs(((mean(observed.a1)+mean(observed.a2))/2)-((mean(observed.b1)+mean(observed.b2))/2))
     }
-    if(statistic=="AA-BB"){
+    else if(statistic=="AA-BB"){
       observed.statistic<-(mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)+mean(observed.b2))
     }
-    if(statistic=="BB-AA"){
+    else if(statistic=="BB-AA"){
       observed.statistic<-(mean(observed.b1)+mean(observed.b2))-(mean(observed.a1)+mean(observed.a2))
     }
-    if(statistic=="|AA-BB|"){
+    else if(statistic=="|AA-BB|"){
       observed.statistic<-abs((mean(observed.a1)+mean(observed.a2))-(mean(observed.b1)+mean(observed.b2)))
     }
+    else{
+      A1<-observed.a1
+      B1<-observed.b1	
+      A2<-observed.a2
+      B2<-observed.b2
+      A<-observed.a
+      B<-observed.b
+      observed.statistic<-eval(parse(text=statistic))
+    }
   }
   
   if(design=="MBD"){
@@ -94,27 +116,31 @@ function(design,statistic,data=read.table(file.choose(new=FALSE))){
     for(it in 1:(ncol(data)/2)){
       observed.b[[it]]<-data[,it*2][data[,(it*2)-1]=="B"]
     }
+    differences<-numeric(ncol(data)/2)
     if(statistic=="A-B"){
-      differences<-numeric(ncol(data)/2)
       for(it in 1:(ncol(data)/2)){
         differences[it]<-mean(observed.a[[it]])-mean(observed.b[[it]])
       }
     }
-    if(statistic=="B-A"){
-      differences<-numeric(ncol(data)/2)
+    else if(statistic=="B-A"){
       for(it in 1:(ncol(data)/2)){
         differences[it]<-mean(observed.b[[it]])-mean(observed.a[[it]])
       }
     }
-    if(statistic=="|A-B|"){
-      differences<-numeric(ncol(data)/2)
+    else if(statistic=="|A-B|"){
       for(it in 1:(ncol(data)/2)){
         differences[it]<-abs(mean(observed.a[[it]])-mean(observed.b[[it]]))
       }
     }
+    else{
+      for(it in 1:(ncol(data)/2)){
+        A<-observed.a[[it]]
+        B<-observed.b[[it]]
+        differences[it]<-eval(parse(text=statistic))
+      }
+    }
     observed.statistic<-mean(differences)
   }
   
   return(observed.statistic)
-
 }
